==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/NumberLessThanOrEqualsFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * NumberLessThanOrEquals Filter.
 * @property key The field/property in the event based on which you want to filter.
 * @property operatorType The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
 * Expected value is 'NumberLessThanOrEquals'.
 * @property value The filter value.
 */
public data class NumberLessThanOrEqualsFilterArgs(
    public val key: Output<String>? = null,
    public val operatorType: Output<String>,
    public val `value`: Output<Double>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs =
        com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .operatorType(operatorType.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NumberLessThanOrEqualsFilterArgs].
 */
@PulumiTagMarker
public class NumberLessThanOrEqualsFilterArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var operatorType: Output<String>? = null

    private var `value`: Output<Double>? = null

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("gpdocearppnhdnib")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberLessThanOrEquals'.
     */
    @JvmName("hogdsdsaodlabtxf")
    public suspend fun operatorType(`value`: Output<String>) {
        this.operatorType = value
    }

    /**
     * @param value The filter value.
     */
    @JvmName("lmfetahushtkpklk")
    public suspend fun `value`(`value`: Output<Double>) {
        this.`value` = value
    }

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("yuerohfhqjrxlgwo")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberLessThanOrEquals'.
     */
    @JvmName("lqtuancldvfgeflw")
    public suspend fun operatorType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operatorType = mapped
    }

    /**
     * @param value The filter value.
     */
    @JvmName("dihhaphpoinabxxj")
    public suspend fun `value`(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): NumberLessThanOrEqualsFilterArgs = NumberLessThanOrEqualsFilterArgs(
        key = key,
        operatorType = operatorType ?: throw PulumiNullFieldException("operatorType"),
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/eventgrid/kotlin/inputs/NumberLessThanOrEqualsFilterArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.eventgrid.kotlin.inputs

import com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Double
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * NumberLessThanOrEquals Filter.
 * @property key The field/property in the event based on which you want to filter.
 * @property operatorType The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
 * Expected value is 'NumberLessThanOrEquals'.
 * @property value The filter value.
 */
public data class NumberLessThanOrEqualsFilterArgs(
    public val key: Output<String>? = null,
    public val operatorType: Output<String>,
    public val `value`: Output<Double>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs> {
    override fun toJava(): com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs =
        com.pulumi.azurenative.eventgrid.inputs.NumberLessThanOrEqualsFilterArgs.builder()
            .key(key?.applyValue({ args0 -> args0 }))
            .operatorType(operatorType.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NumberLessThanOrEqualsFilterArgs].
 */
@PulumiTagMarker
public class NumberLessThanOrEqualsFilterArgsBuilder internal constructor() {
    private var key: Output<String>? = null

    private var operatorType: Output<String>? = null

    private var `value`: Output<Double>? = null

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("qskrpdorcuqwhcvc")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberLessThanOrEquals'.
     */
    @JvmName("hysmquhifqdrwvxy")
    public suspend fun operatorType(`value`: Output<String>) {
        this.operatorType = value
    }

    /**
     * @param value The filter value.
     */
    @JvmName("rcwydcpfcjyaimdf")
    public suspend fun `value`(`value`: Output<Double>) {
        this.`value` = value
    }

    /**
     * @param value The field/property in the event based on which you want to filter.
     */
    @JvmName("hsdnjljcnxateskx")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The operator type used for filtering, e.g., NumberIn, StringContains, BoolEquals and others.
     * Expected value is 'NumberLessThanOrEquals'.
     */
    @JvmName("gjodcbiltommannq")
    public suspend fun operatorType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.operatorType = mapped
    }

    /**
     * @param value The filter value.
     */
    @JvmName("qrqkoxxmogvisgpt")
    public suspend fun `value`(`value`: Double?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): NumberLessThanOrEqualsFilterArgs = NumberLessThanOrEqualsFilterArgs(
        key = key,
        operatorType = operatorType ?: throw PulumiNullFieldException("operatorType"),
        `value` = `value`,
    )
}
